import Qt 4.7
import "imports/colibri"
import "imports/XAComponents"
import "AICalendarPickerJS.js" as XACalJS

Rectangle {
    id: aiProtectionLevelPicker

    color: "transparent"

    property string windowGotFocus : qtWindowGotFocus
    property string dtsSecurityLevel : qtProtectionLevel

    property bool enabled: true

    function onPresetValuesCompleted() {
//        console.debug("QML XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX VALUES LOADED.");
//        console.debug(dtsSecurityLevel + " / " + qtProtectionLevel)

        dtsSecurityLevel = qtProtectionLevel;
        updateToolTip(dtsSecurityLevel);
    }

//    onFocusChanged: console.debug("AICalendarPicker: focus changed.")

    Component.onCompleted: {
//        console.debug("QML XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX Component.onCompleted.");
    }

    function doOp(level) {
        dtsSecurityLevel = level;
        QtHandler.protectionLevelSelected(level)
    }

    function updateToolTip(displayLevel) {
        var level = displayLevel;
        if (level == -1) level = dtsSecurityLevel;

        if (displayLevel == 0) {
            footerLabel.text = qsTr("L0: Unclassified");
            footerDetailLabel.text = qsTr("Without classification. No damage if publicly available.")

        } else if (displayLevel == 1) {
            footerLabel.text = qsTr("L1: Controlled Unclassified");
            footerDetailLabel.text = qsTr("Without classification. Only shared in controlled environments.")

        } else if (displayLevel == 2) {
            footerLabel.text = qsTr("L2: Restricted");
            footerDetailLabel.text = qsTr("Material that would cause 'undesirable effects' if it were public.")

        } else if (displayLevel == 3) {
            footerLabel.text = qsTr("L3: Confidential");
            footerDetailLabel.text = qsTr("Material that would cause 'damage' if it were public.")

        } else if (displayLevel == 4) {
            footerLabel.text = qsTr("L4: Secret");
            footerDetailLabel.text = qsTr("Material that would cause 'grave damage' if it were public.")

        } else if (displayLevel == 5) {
            footerLabel.text = qsTr("L5: Top Secret");
            footerDetailLabel.text = qsTr("Material that would cause 'exceptionally grave damage' if it were public.")

        } else {
            footerLabel.text = qsTr("Unclassified");
            footerDetailLabel.text = qsTr("Without classification. No damage if publicly available.")
        }

    }

    Rectangle {
        id: closeTab
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.leftMargin: parent.width / 2 - 7
        width: 16
        height: 30

        color: "#99222222"

        Image {
            anchors.left: parent.left
            anchors.top: parent.top
            source: "imports/XAComponents/pics/PreviewIconLockPopupButtonPressed16px.png"
        }

        MouseArea {
            id: closeTabMouseArea
            anchors.fill: parent

            onClicked: QtWindow.hide();
        }

    }


    Rectangle {
        id: contentRectangle
        anchors.top: parent.top
        anchors.topMargin: 16
        anchors.left: parent.left
        anchors.right: parent.right
        height: 80

        gradient: Gradient {
            GradientStop { position: 0; color: "#222222" }
            GradientStop { position: 0.5; color: "#3f3b3c" }
            GradientStop { position: 1; color: "#222222" }
        }

        radius: 0
        smooth: true

        Rectangle {
            id: securityLockRect
            anchors.top: parent.top
            anchors.horizontalCenter: parent.horizontalCenter
            height: 32
            width: 144
            color: "transparent"

            XASecurityLockButton {
                id: securityLockL0
                anchors.left: parent.left
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5

                level: 0
                selected: (dtsSecurityLevel < 1) ? 1 : 0

                MouseArea {
                    id: mouseAreaL0
                    anchors.fill: parent
                    hoverEnabled: true

                    onEntered: updateToolTip(0);
                    onExited: updateToolTip(dtsSecurityLevel);

                    onClicked: doOp(parent.level)
                }
            }

            XASecurityLockButton {
                id: securityLockL1
                anchors.left: parent.left
                anchors.leftMargin: 25
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5

                level: 1
                selected: (dtsSecurityLevel == 1) ? 1 : 0

                MouseArea {
                    id: mouseAreaL1
                    anchors.fill: parent
                    hoverEnabled: true

                    onEntered: updateToolTip(1);
                    onExited: updateToolTip(dtsSecurityLevel);

                    onClicked: doOp(parent.level)
                }
            }

            XASecurityLockButton {
                id: securityLockL2
                anchors.left: parent.left
                anchors.leftMargin: 50
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5

                level: 2
                selected: (dtsSecurityLevel == 2) ? 1 : 0

                MouseArea {
                    id: mouseAreaL2
                    anchors.fill: parent
                    hoverEnabled: true

                    onEntered: updateToolTip(2);
                    onExited: updateToolTip(dtsSecurityLevel);

                    onClicked: doOp(parent.level)
                }
            }

            XASecurityLockButton {
                id: securityLockL3
                anchors.left: parent.left
                anchors.leftMargin: 75
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5

                level: 3
                selected: (dtsSecurityLevel == 3) ? 1 : 0

                MouseArea {
                    id: mouseAreaL3
                    anchors.fill: parent
                    hoverEnabled: true

                    onEntered: updateToolTip(3);
                    onExited: updateToolTip(dtsSecurityLevel);

                    onClicked: doOp(parent.level)
                }
            }

            XASecurityLockButton {
                id: securityLockL4
                anchors.left: parent.left
                anchors.leftMargin: 100
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5

                level: 4
                selected: (dtsSecurityLevel == 4) ? 1 : 0

                MouseArea {
                    id: mouseAreaL4
                    anchors.fill: parent
                    hoverEnabled: true

                    onEntered: updateToolTip(4);
                    onExited: updateToolTip(dtsSecurityLevel);

                    onClicked: doOp(parent.level)
                }
            }

            XASecurityLockButton {
                id: securityLockL5
                anchors.left: parent.left
                anchors.leftMargin: 125
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 5

                level: 5
                selected: (dtsSecurityLevel == 5) ? 1 : 0

                MouseArea {
                    id: mouseAreaL5
                    anchors.fill: parent
                    hoverEnabled: true

                    onEntered: updateToolTip(5);
                    onExited: updateToolTip(dtsSecurityLevel);

                    onClicked: doOp(parent.level)
                }
            }


        }

        XAHDivisionLine {
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottomMargin: 45
        }

        Rectangle {
            id: footerRect
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            anchors.leftMargin: 25
            anchors.right: parent.right
            anchors.rightMargin: 25
            height: 38

            color: "transparent"

            Text {
                id: footerLabel
                anchors.fill: parent

                color: "white"
                font.family: "Arial"
                font.pixelSize: 12
                font.bold: true
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignTop
            }

            Text {
                id: footerDetailLabel
                anchors.fill: parent
                anchors.topMargin:15

                color: "white"
                font.family: "Arial"
                font.pixelSize: 11
                font.bold: false
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignTop
            }
        }

    }

}


