import QtQuick 1.1

Item {
    id: maincomponent
    height: 21
    width: 80

    property bool isSelected: false
    property bool displayAsColorBlock: false
    property alias icon: selectionPanelIcon.source
    property alias iconVisible: selectionPanelIcon.visible
    property alias text: selectionPanelTitle.text
    property alias textVisible: selectionPanelTitle.visible
    property alias backgroundColor: selectionPanelTab.color
    property alias selectionColor: selectionPanelBottomLine.color
    property alias colorBlockColor: selectionPanelColorBlock.color
    property color colorBlockBorder: "transparent"
    property color colorBlockSelectedBorder: "transparent"

    signal triggered();

    onDisplayAsColorBlockChanged: {
        if (displayAsColorBlock) {
            selectionPanelIcon.visible = false
            selectionPanelTitle.visible = false
            selectionPanelColorBlock.visible = true
            selectionPanelBottomLine.visible = false

        } else {
            selectionPanelIcon.visible = (selectionPanelIcon.sourceSize.width > 0)
            selectionPanelTitle.visible = true
            selectionPanelColorBlock.visible = false
            selectionPanelBottomLine.visible = maincomponent.isSelected
        }
    }

    Rectangle {
        id: selectionPanelTab
        anchors.fill: parent

        Item {
            id: selectionPanelContent
            width: {
                var calc = 0;
                if (displayAsColorBlock) calc = maincomponent.height
                else {
                    if (selectionPanelIcon.visible) calc += selectionPanelIcon.width
                    if (selectionPanelTitle.visible) calc += selectionPanelTitle.width
                    if (selectionPanelIcon.visible && selectionPanelTitle.visible) calc += 10
                }
                return calc;
            }
            anchors.left: parent.left
            anchors.leftMargin: (parent.width - width) / 2
            anchors.top: parent.top
            anchors.bottom: parent.bottom

            Image {
                id: selectionPanelIcon
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -2
                anchors.left: parent.left

                fillMode: Image.PreserveAspectFit
                smooth: true

                visible: (sourceSize.width > 0)
            }

            Text {
                id: selectionPanelTitle
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -1
                anchors.left: parent.left
                anchors.leftMargin: (selectionPanelIcon.visible) ? selectionPanelIcon.width + 10 : 0

                smooth: true
            }

            Rectangle {
                id: selectionPanelColorBlock
                anchors.fill: parent

                border.width: 2
                border.color: maincomponent.isSelected ? maincomponent.colorBlockSelectedBorder : maincomponent.colorBlockBorder

                visible: false
            }
        }

        Rectangle {
            id: selectionPanelBottomLine
            anchors.left: parent.left
            anchors.bottom: parent.bottom
            anchors.right: parent.right
            height: 3

            visible: maincomponent.isSelected
        }

        MouseArea {
            anchors.fill: parent
            onPressed: triggered();
        }
    }
}
